'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }(); /*
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     * Library
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     */


var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/*
* Util methods
*/
var Util = function () {
  function Util() {
    _classCallCheck(this, Util);
  }

  _createClass(Util, null, [{
    key: 'deepObfuscateValue',


    /*
    * Recursive class to obfuscate attribute in a payload
    *
    * @params [Object] payload to obfuscate
    * @params [Array] field names to obfuscate
    *
    * @return [Object]
    */
    value: function deepObfuscateValue(payload, fields) {
      var _this = this;

      if (_lodash2.default.isArray(payload)) {
        return payload.map(function (e) {
          return _this.deepObfuscateValue(e, fields);
        });
      } else if (_lodash2.default.isObjectLike(payload)) {
        var copy = {};

        Object.keys(payload).forEach(function (key) {
          copy[key] = fields.includes(key) ? '[HIDDEN]' : _this.deepObfuscateValue(payload[key], fields);
        });

        return copy;
      }

      return payload;
    }

    /*
    * Underscore a string
    *
    * @params [String] string to transform
    *
    * @return [String] transformed
    */

  }, {
    key: 'underscore',
    value: function underscore(str) {
      return str.replace(/([a-z\d])([A-Z]+)/g, '$1_$2').replace(/[-\s]+/g, '_').toLowerCase();
    }

    /*
    * Recursive class to underscore attributes in a payload
    *
    * @params [Object] payload to transform
    * @params [func] called for every object value
    *
    * @return [Object] transformed
    */

  }, {
    key: 'deepUnderscore',
    value: function deepUnderscore(payload) {
      var _this2 = this;

      var objectReplacer = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;

      var copy = {};

      Object.keys(payload).forEach(function (key) {
        var value = payload[key];

        if (_lodash2.default.isArray(value)) {
          copy[_this2.underscore(key)] = value.map(function (v) {
            return _lodash2.default.isObjectLike(v) ? _this2.deepUnderscore(v, objectReplacer) : v;
          });
        } else if (_lodash2.default.isObjectLike(value)) {
          var newValue = !objectReplacer ? value : objectReplacer(value);

          copy[_this2.underscore(key)] = _lodash2.default.isObjectLike(newValue) ? _this2.deepUnderscore(newValue, objectReplacer) : newValue;
        } else {
          copy[_this2.underscore(key)] = value;
        }
      });

      return copy;
    }

    /*
    * Remove null, undefined value from an object
    *
    * @params [Object] payload to transform
    *
    * @return [Object] transformed
    */

  }, {
    key: 'compact',
    value: function compact(object) {
      var _this3 = this;

      var clone = void 0;

      if (_lodash2.default.isArray(object)) {
        clone = [];

        object.forEach(function (value) {
          if (!_this3.isBlank(value)) clone.push(value);
        });
      } else {
        clone = _lodash2.default.clone(object);

        Object.keys(object).forEach(function (key) {
          if (_this3.isBlank(object[key])) delete clone[key];
        });
      }

      return clone;
    }

    /*
    * Remove null, undefined value from an object
    *
    * @params [Object] payload to transform
    *
    * @return [Object] transformed
    */

  }, {
    key: 'deepCompact',
    value: function deepCompact(object) {
      var _this4 = this;

      var clone = _lodash2.default.clone(object);

      Object.keys(clone).forEach(function (key) {
        var value = clone[key];

        if (_lodash2.default.isArray(value)) {
          clone[key] = _this4.compact(value.map(function (v) {
            if (_this4.isBlank(v)) return null;else if (_lodash2.default.isObjectLike(v)) return _this4.deepCompact(v);

            return v;
          }));
        } else if (_lodash2.default.isObjectLike(value)) {
          clone[key] = _this4.deepCompact(value);
        } else if (_this4.isBlank(value)) {
          delete clone[key];
        }
      });

      return clone;
    }

    /*
    * Check if an object is blank
    *
    * @params [Any Object] to verify
    *
    * @return [Boolean]
    */

  }, {
    key: 'isBlank',
    value: function isBlank(object) {
      switch (typeof object === 'undefined' ? 'undefined' : _typeof(object)) {
        case 'boolean':
          return false;
        case 'function':
          return false;
        case 'number':
          return _lodash2.default.isNaN(object);
        default:
          return _lodash2.default.isEmpty(object);
      }
    }

    /*
    * lookup path in a nested object
    *
    * @param [Object]
    * @param [Args] path to lookup
    *
    * @return [Object] value of the path
    */

  }, {
    key: 'lookup',
    value: function lookup(object) {
      var obj = object;

      for (var _len = arguments.length, args = Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
        args[_key - 1] = arguments[_key];
      }

      for (var i = 0; i < args.length; i++) {
        try {
          if (!obj || !(args[i] in obj)) {
            return undefined;
          }
        } catch (e) {
          return undefined;
        }

        obj = obj[args[i]];
      }

      return obj;
    }

    /*
    * Transform object into url string params
    *
    * @param [Object] List of params
    *
    * @return [String] params for url
    */

  }, {
    key: 'toUrlParams',
    value: function toUrlParams(object) {
      return Object.keys(object).map(function (key) {
        return encodeURIComponent(key) + '=' + encodeURIComponent(object[key]);
      }).join('&');
    }
  }]);

  return Util;
}();

exports.default = Util;